@@ -1,7 +1,7 @@
 from __future__ import absolute_import
 import sys
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 # Python 2 vs 3
 PY3 = sys.version_info[0] == 3
@@ -9,8 +9,7 @@ PY3 = sys.version_info[0] == 3
 # Platform specific imports
 if sys.platform.startswith('win'):
     import xlwings._xlwindows as xlplatform
-
-if sys.platform.startswith('darwin'):
+else:
     import xlwings._xlmac as xlplatform
 
 # API
